@@ -12,9 +12,7 @@ from rpi_featureSelection_python_tools.stmb_tools import *
 # at once in the future, if needed. Otherwise, one could simply inline all these.
 Inputs = ndarray
 Outputs = ndarray
-Params = NamedTuple('Params', [
-    ('estimators', List[]),
-])
+Params = TypeVar('Params')
 
 class STMBFeatureSelector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params]):
 
